/**
 * Copyright (C) 2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.server.session;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * Contains the information of a running sync
 * @version $Id: RunningSync.java,v 1.1 2007/04/06 16:37:07 nichele Exp $
 */
public class RunningSync {

    // -------------------------------------------------------------- Properties

    /**
     * The session id
     */
    private String sessionId    = null;

    public String getSessionId() {
        return sessionId;
    }

    public void setSessionId(String sessionId) {
        this.sessionId = sessionId;
    }

    /**
     * The node id. Unique identifier of the ds server instance
     * (needed in a cluster environment)
     */
    private String node       = null;

    public String getNode() {
        return node;
    }

    public void setNode(String node) {
        this.node = node;
    }

    /**
     * The principal
     */
    private long   principal  = 0;

    public long getPrincipal() {
        return principal;
    }

    public void setPrincipal(long principal) {
        this.principal = principal;
    }

    /**
     * The user name
     */
    private String username   = null;

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    /**
     * The device id
     */
    private String device     = null;

    public String getDevice() {
        return device;
    }

    public void setDevice(String device) {
        this.device = device;
    }

    /**
     * The start sync timestamp
     */
    private long   startSync = 0;

    public long getStartSync() {
        return startSync;
    }

    public void setStartSync(long startSync) {
        this.startSync = startSync;
    }

    // ------------------------------------------------------------ Constructors

    /**
     * Creates a new instance of RunningSync
     */
    public RunningSync() {
    }

    /**
     * Creates a new instance of RunningSync
     * @param session the session id
     * @param node the node
     * @param principal the principal
     * @param username the username
     * @param device the device
     * @param startSync the start sync time
     */
    public RunningSync(String sessionId,
                       String node,
                       long   principal,
                       String username,
                       String device,
                       long   startSync) {

        this.sessionId   = sessionId;
        this.node        = node;
        this.principal   = principal;
        this.username    = username;
        this.device      = device;
        this.startSync   = startSync;
    }

    /**
     * Returns a string representation of this object
     * @return a string representation of this object
     */
    public String toString() {
        ToStringBuilder sb = new ToStringBuilder(this);
        sb.append("username" , username);
        sb.append("sessionId", sessionId);
        sb.append("node"     , node);
        sb.append("principal", principal);
        sb.append("device"   , device);
        sb.append("startSync", startSync);
        return sb.toString();
    }
}
