/**
 * Copyright (C) 2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.server.update;

import java.io.ByteArrayOutputStream;
import java.io.StringReader;
import java.util.StringTokenizer;

import org.jibx.runtime.BindingDirectory;
import org.jibx.runtime.IBindingFactory;
import org.jibx.runtime.IMarshallingContext;
import org.jibx.runtime.IUnmarshallingContext;
import org.jibx.runtime.JiBXException;

/**
 * Provides useful methods to handle the components
 * @version $Id: Util.java,v 1.1 2007/04/15 20:59:02 nichele Exp $
 */
public class Util {

    // ---------------------------------------------------------- Public methods

    /**
     * Parses the given xml string in order to obtain a ComponentList
     * @param xml the xml to parse
     * @return a ComponentList
     * @throws UpdateException if an error occurs
     */
    public static ComponentList fromXML(String xml) throws UpdateException {
        Object list;
        try {
            IBindingFactory f = BindingDirectory.getFactory(ComponentList.class);
            IUnmarshallingContext c = f.createUnmarshallingContext();
            list = c.unmarshalDocument(new StringReader(xml));
        } catch (JiBXException ex) {
            throw new UpdateException(ex);
        }

        return (ComponentList)list;
    }

    /**
     * Converts the given ComponentList in xml
     * @param list the component list
     * @return a xml representation of the given list
     * @throws UpdateException if an error occurs
     */
    public static String toXML(ComponentList list) throws UpdateException {
        String message = null;

        ByteArrayOutputStream bout = new ByteArrayOutputStream();
        try {

            IBindingFactory f = BindingDirectory.getFactory(ComponentList.class);
            IMarshallingContext c = f.createMarshallingContext();
            c.setIndent(0);
            c.marshalDocument(list, "UTF-8", null, bout);
        } catch (JiBXException ex) {
            throw new UpdateException(ex);
        }

        message = new String(bout.toByteArray());

        return message;
    }

    /**
     * Compares the given version in order to check if v1 is greater than v2.
     * <br/>
     * The versions must be in the form:
     * <code>releaseMajor.releaseMinor.releaseBuildNumber</code>
     * <br/>Examples: 6.0.1, 6.0.12, 6.1.0, 7.0.0
     * @param v1 the first version
     * @param v2 the second version
     * @return  true is v1 is greater than v2
     */
    public static boolean compareVersionNumber(String v1, String v2) {

        StringTokenizer sz1 = new StringTokenizer(v1, ".");
        StringTokenizer sz2 = new StringTokenizer(v2, ".");

        int countToken1 = sz1.countTokens();
        int countToken2 = sz2.countTokens();

        int numTokens = (countToken1 > countToken2 ? countToken1 : countToken2);

        int[] versionNumbers1 = new int[numTokens];
        int[] versionNumbers2 = new int[numTokens];
        int i = 0;
        while (sz1.hasMoreTokens()) {
            versionNumbers1[i++] = Integer.parseInt(sz1.nextToken());
        }
        i = 0;
        while (sz2.hasMoreTokens()) {
            versionNumbers2[i++] = Integer.parseInt(sz2.nextToken());
        }

        for (int j = 0; j < numTokens; j++) {
            if (versionNumbers1[j] > versionNumbers2[j]) {
                return true;
            } else if (versionNumbers1[j] < versionNumbers2[j]) {
                return false;
            }
        }
        return false;

    }

}
